@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -50,6 +50,10 @@ BOOST_AUTO_TEST_CASE_TEMPLATE( test_simple_write_read, T, type )
 {
         C3DBounds size(2,3,4);
 	T3DImage<T> *image = new T3DImage<T>(size); 
+	image->set_voxel_size(C3DFVector(10,20,30)); 
+	image->set_origin(C3DFVector(20,30,40)); 
+	image->set_rotation(C3DRotation(Quaternion(0.5, 0.1, 0.7, 0.5))); 
+	
         P3DImage pimage(image); 
 
         auto iv = image->begin(); 
