@@ -121,7 +121,8 @@ P2DImage C2DMean::do_filter(const C2DImage& image) const
 }
 
 C2DMeanFilterPlugin::C2DMeanFilterPlugin():
-	C2DFilterPlugin("mean")
+	C2DFilterPlugin("mean"), 
+	m_hw(1)
 {
 	add_parameter("w", new CIntParameter(m_hw, 0, numeric_limits<int>::max(), false, "half filter width"));
 }
