@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,7 +22,6 @@
 
 #include <mia/core/datapool.hh>
 #include <mia/2d/transformfactory.hh>
-#include <mia/2d/inittesthandlers.hh>
 #include <mia/2d/transformio.hh>
 #include <mia/2d/filter/transform.hh>
 
@@ -30,8 +29,6 @@
 using namespace transform_2dimage_filter; 
 using namespace mia; 
 
-C2DTransformCreatorHandlerTestPath transformhandler_init_path; 
-
 struct TransformFixture {
 
 	TransformFixture();
