@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,9 +26,6 @@
 using namespace mia; 
 using namespace std; 
 
-C3DFilterPluginHandlerTestPath filter_test_path; 
-C3DShapePluginHandlerTestPath shape_test_path; 
-
 BOOST_AUTO_TEST_CASE ( test_seeded_watershead ) 
 {
 	const C3DBounds size(11, 10, 3); 
