@@ -27,8 +27,6 @@
 NS_MIA_USE
 
 using namespace std;
-using namespace ::boost;
-using namespace boost::unit_test;
 
 struct DeformFixture {
 	DeformFixture();
