@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,9 +27,6 @@
 NS_MIA_USE; 
 using namespace std; 
 
-CSplineKernelTestPath splinekernel_init_path; 
-C3DTransformCreatorHandlerTestPath transform_creator_test_path; 
-
 
 namespace bfs=::boost::filesystem; 
 class PrepareTransIOTests {
@@ -74,6 +71,7 @@ BOOST_AUTO_TEST_CASE(test_transform_io)
 		for (size_t k = 0; k < params.size(); ++k) 
 			params[k] = k + 1; 
 		tr->set_parameters(params);
+		tr->set_attribute("string_attr", "string"); 
 		
 		for (size_t i = 0; i < n_io; ++i) {
 			stringstream fname; 
@@ -90,6 +88,10 @@ BOOST_AUTO_TEST_CASE(test_transform_io)
 			BOOST_CHECK_EQUAL(lparams.size(), params.size()); 
 			for (size_t k = 0; k < lparams.size(); ++k) 
 				BOOST_CHECK_EQUAL(lparams[k], k + 1); 
+			
+			BOOST_REQUIRE(t_loaded->has_attribute("string_attr")); 
+			BOOST_CHECK_EQUAL(t_loaded->get_attribute_as<string>("string_attr"), "string"); 
+
 			unlink( fname.str().c_str()); 
 
 		}
