@@ -18,17 +18,21 @@
  *
  */
 
+#include <cassert>
 #include <mia/core/typedescr.hh>
 #include <mia/core/cmdbooloption.hh>
 
 NS_MIA_BEGIN
 
 
-CCmdBoolOption::CCmdBoolOption(bool& value, char short_opt, const char *long_opt, const char *long_help):
-	CCmdOption(short_opt, long_opt, long_help, long_opt, false), 
+CCmdBoolOption::CCmdBoolOption(bool& value, char short_opt, const char *long_opt, const char *long_help, 
+			       CCmdOptionFlags flags):
+	CCmdOption(short_opt, long_opt, long_help, long_opt, flags), 
 	m_value(value)
 {
 	m_value = false; 
+
+	assert(!has_flag(CCmdOptionFlags::required) && "A boolean flag option must not have the flag CCmdOptionFlags::required"); 
 }
 
 bool CCmdBoolOption::do_set_value(const char */*str_value*/)
