@@ -89,6 +89,8 @@ struct CCmdOptionListData {
 	bool copyright;
 	vstream::Level verbose;
 	int max_threads;
+	bool m_selftest_run; 
+	bool m_stdout_is_result; 
 
 	CCmdOptionListData(const SProgramDescription& description); 
 
@@ -125,6 +127,44 @@ struct CCmdOptionListData {
 	ostream *m_log; 
 };
 
+
+/**
+   This option is used to run a selftest. 
+
+   A program can only have one selftest option and all other options that are not 
+   in the Help & Info section are ignored when the selftest option is set. 
+   The selftest is done within a class derived from the CSelftestOption::Callback 
+   class that overrides the Callback::do_run() method. 
+*/
+class EXPORT_CORE CSelftestOption: public CCmdOption {
+public: 
+        /**
+           Test callback base class. 
+
+           The tests to be run must be implemented in the "int do_run() const"  method, and 
+           it must return 0 if the test run successfull. 
+         */
+
+
+
+private: 
+        friend class CCmdOptionList; 
+        /**
+           Constructor of the selftest function 
+        */
+        CSelftestOption(bool& run, int& test_result, CSelftestCallback *callback);
+        
+
+        virtual bool do_set_value(const char *str_value);
+	virtual void do_write_value(std::ostream& os) const;
+        virtual size_t do_get_needed_args() const; 
+        
+        std::unique_ptr<CSelftestCallback> m_callback;
+        int& m_test_result;
+        bool& m_run; 
+        
+}; 
+
 void CCmdOptionListData::set_logstream(ostream& os)
 {
 	m_log  = &os; 
@@ -169,6 +209,8 @@ CCmdOptionListData::CCmdOptionListData(const SProgramDescription& description):
 #else 
 	max_threads(tbb::task_scheduler_init::automatic), 
 #endif 
+	m_selftest_run(false), 
+	m_stdout_is_result(false), 
 	m_log(&std::cout)
 {
 
@@ -185,11 +227,11 @@ CCmdOptionListData::CCmdOptionListData(const SProgramDescription& description):
 	add(make_opt(verbose, g_verbose_dict, "verbose",  'V', 
 		     "verbosity of output, print messages of given level and higher priorities."
 		     " Supported priorities starting at lowest level are:"));
-	add(make_opt(copyright,  "copyright", 0, "print copyright information"));
-	add(make_opt(help,  "help", 'h', "print this help"));
-	add(make_opt(help_xml,  "help-xml", 0, "print help formatted as XML"));
-	add(make_opt(usage,  "usage", '?', "print a short help"));
-	add(make_opt(version,  "version", 0, "print the version number and exit"));
+	add(make_opt(copyright,  "copyright", 0, "print copyright information", CCmdOptionFlags::nonipype));
+	add(make_opt(help,  "help", 'h', "print this help", CCmdOptionFlags::nonipype));
+	add(make_opt(help_xml,  "help-xml", 0, "print help formatted as XML", CCmdOptionFlags::nonipype));
+	add(make_opt(usage,  "usage", '?', "print a short help", CCmdOptionFlags::nonipype));
+	add(make_opt(version,  "version", 0, "print the version number and exit", CCmdOptionFlags::nonipype));
 
 	set_current_group("Processing"); 
 	add(make_opt(max_threads, "threads", 0, "Maxiumum number of threads to use for processing," 
@@ -236,6 +278,7 @@ void CCmdOptionListData::add(const string& group, PCmdOption opt)
 	if (options.find(group) == options.end()) 
 		options[group] = vector<PCmdOption>();
 	options[group].push_back(opt); 
+	opt->add_option(short_map, long_map);
 }
 
 CHistoryRecord CCmdOptionListData::get_values() const
@@ -277,7 +320,8 @@ void CCmdOptionListData::print_help_xml(const char *name_help, const CPluginHand
 	Element* nodeRoot = doc->create_root_node("program");
 	Element* program_name = nodeRoot->add_child("name"); 
 	program_name->set_child_text(name_help); 
-
+	Element*  version_string = nodeRoot->add_child("version"); 
+	version_string->set_child_text(get_revision()); 
 	Element* program_group = nodeRoot->add_child("section"); 
 	program_group->set_child_text(m_program_group); 
 	Element* description = nodeRoot->add_child("description"); 
@@ -286,6 +330,7 @@ void CCmdOptionListData::print_help_xml(const char *name_help, const CPluginHand
 	Element*  short_descr = nodeRoot->add_child("whatis"); 
 	short_descr->set_child_text(m_short_descr); 
 
+
 	ostringstream usage_text; 
 	usage_text << " " << name_help << " "; 
 
@@ -319,6 +364,10 @@ void CCmdOptionListData::print_help_xml(const char *name_help, const CPluginHand
 		free_parameters->set_attribute("name", additional_help->get_descriptor()); 
 		free_parameters->set_attribute("type", "factory"); 
 	}
+	
+	if (m_stdout_is_result) {
+		nodeRoot->add_child("stdout-is-result");
+	}
 		
 	usage_text << "[options]"; 
 	if (additional_help) 
@@ -506,7 +555,7 @@ void CCmdOptionListData::print_usage(const char *name) const
 
 void CCmdOptionListData::print_version(const char *name_help) const
 {
-	*m_log << name_help << " revision:" << get_revision() << "\n\n"; 
+	*m_log << name_help << " version: " << get_revision() << "\n\n"; 
 	*m_log << g_basic_copyright1; 
 	*m_log << get_author(); 
 	*m_log << g_basic_copyright2 << "\n"; 
@@ -527,6 +576,11 @@ void CCmdOptionList::add(const std::string& table, PCmdOption opt)
 	m_impl->add(table, opt);
 }
 
+void CCmdOptionList::add_selftest(int& test_result, CSelftestCallback *callback)
+{
+	m_impl->add("Test", PCmdOption(new CSelftestOption(m_impl->m_selftest_run, test_result, callback))); 
+}
+
 void CCmdOptionList::set_group(const std::string& group)
 {
 	m_impl->set_current_group(group); 
@@ -624,6 +678,11 @@ CCmdOptionList::parse(size_t argc, char *args[], const string& additional_type,
 	return do_parse(argc, (const char **)args, true, additional_help);
 }
 
+void CCmdOptionList::set_stdout_is_result()
+{
+	m_impl->m_stdout_is_result = true; 
+}
+
 struct TBBTaskScheduler {
 	static const tbb::task_scheduler_init& initialize(int max_threads);
 }; 
@@ -720,6 +779,8 @@ CCmdOptionList::do_parse(size_t argc, const char *args[], bool has_additional,
 	} else if (m_impl->copyright) {
 		::print_full_copyright(name_help, m_impl->get_author());
 		return hr_copyright;
+	} else if (m_impl->m_selftest_run) {
+		return hr_selftest; 
 	}
 
 	cverb.set_verbosity(m_impl->verbose);
@@ -776,42 +837,6 @@ CHistoryRecord CCmdOptionList::get_values() const
 	return m_impl->get_values();
 }
 
-CHelpOption::CHelpOption(Callback *cb, char short_opt, const char *long_opt, const char *long_help):
-	CCmdOption(short_opt, long_opt, long_help, NULL, CCmdOptionFlags::none), 
-	m_callback(cb)
-{
-}
-
-void CHelpOption::do_get_long_help_xml(std::ostream& os, xmlpp::Element& parent, 
-				       HandlerHelpMap& /*handler_map*/) const
-{
-	do_get_long_help(os);
-	parent.set_attribute("type", "bool");
-}
-
-
-void CHelpOption::print(std::ostream& os) const
-{
-	m_callback->print(os);
-}
-
-bool CHelpOption::do_set_value(const char */*str_value*/)
-{
-	exit(0); 
-}
-size_t CHelpOption::do_get_needed_args() const
-{
-	return 0; 
-}
-
-void CHelpOption::do_get_long_help(std::ostream& /*os*/) const
-{
-}
-
-void CHelpOption::do_write_value(std::ostream& /*os*/) const
-{
-}
-
 CCmdFlagOption::CCmdFlagOption(int& val, const CFlagString& map, char short_opt, 
 			       const char *long_opt, const char *long_help, 
 			       const char *short_help, 
@@ -849,6 +874,35 @@ size_t CCmdFlagOption::do_get_needed_args() const
 	return 1;
 }
 
+
+CSelftestOption::CSelftestOption(bool& run, int& test_result, CSelftestCallback *callback):
+        CCmdOption(0, "selftest", "run a self test of the program", 0, 
+                   CCmdOptionFlags::nonipype), 
+        m_callback(callback), 
+        m_test_result(test_result), 
+        m_run(run)
+{
+        
+}
+
+
+bool CSelftestOption::do_set_value(const char * /* str_value */)
+{
+        assert(m_callback); 
+        m_test_result = m_callback->run();
+        m_run = true;
+        return true; 
+}
+
+void CSelftestOption::do_write_value(std::ostream& /* os */) const
+{
+}
+
+size_t CSelftestOption::do_get_needed_args() const
+{
+        return 0; 
+}
+
 PCmdOption EXPORT_CORE make_opt(int& value, const CFlagString& map, const char *long_opt, 
 				char short_opt,const char *long_help, 
 				const char *short_help, CCmdOptionFlags flags)
@@ -858,12 +912,6 @@ PCmdOption EXPORT_CORE make_opt(int& value, const CFlagString& map, const char *
 }
 
 
-PCmdOption EXPORT_CORE make_help_opt(const char *long_opt, char short_opt, 
-				     const char *long_help, CHelpOption::Callback *cb)
-{
-	return PCmdOption(new CHelpOption(cb, short_opt, long_opt, long_help));
-}
-
 PCmdOption EXPORT_CORE make_opt(std::string& value, const char *long_opt, char short_opt, const char *long_help, 
 				CCmdOptionFlags flags, const CPluginHandlerBase *plugin_hint)
 {
@@ -871,50 +919,12 @@ PCmdOption EXPORT_CORE make_opt(std::string& value, const char *long_opt, char s
 					       flags, plugin_hint)); 
 }
 
-PCmdOption EXPORT_CORE make_opt(bool& value, const char *long_opt, char short_opt, const char *help)
+PCmdOption EXPORT_CORE make_opt(bool& value, const char *long_opt, char short_opt, const char *help, 
+				CCmdOptionFlags flags)
 {
-	return PCmdOption(new CCmdBoolOption(value, short_opt, long_opt, help ));
+	return PCmdOption(new CCmdBoolOption(value, short_opt, long_opt, help, flags ));
 }
 
 
-//
-// Implementation of the standard option that holds a value
-//
-#if 0
-CBooleanCmdOption::CBooleanCmdOption(T& val, char short_opt, const char *long_opt, const char *long_help):
-        CCmdOption(short_opt, long_opt, long_help, short_help, flags), 
-	m_value(val)
-{
-	m_value = false; 
-}
-
-
-bool CBooleanCmdOption::do_set_value(const char *svalue)
-{
-	m_value = true;
-	return true; 
-}
-
-
-size_t CBooleanCmdOption::do_get_needed_args() const
-{
-        return 0;
-}
-
-
-void CBooleanCmdOption::do_get_long_help(std::ostream& /*os*/) const
-{
-}
-
-
-void CBooleanCmdOption::do_write_value(std::ostream& /*os*/) const
-{
-}
-
-const std::string CBooleanCmdOption::do_get_value_as_string() const
-{
-	return m_value ? "true" : "false";
-}
-#endif 
 
 NS_MIA_END
