@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,10 +21,12 @@
 #include <mia/core/export_handler.hh>
 
 #include <mia/core/cost.hh>
+#include <mia/template/masked_cost.hh>
 
 NS_MIA_BEGIN
 
 const char *cost_type::type_descr = "cost";
+const char *masked_cost_type::type_descr = "maskedcost";
 
 NS_MIA_END
 
