@@ -1,7 +1,7 @@
 /* -*- mia-c++  -*-
  *
  * This file is part of MIA - a toolbox for medical image analysis 
- * Copyright (c) Leipzig, Madrid 1999-2013 Gert Wollny
+ * Copyright (c) Leipzig, Madrid 1999-2014 Gert Wollny
  *
  * MIA is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,8 +39,6 @@ using namespace std;
 using namespace boost::unit_test;
 namespace bfs = ::boost::filesystem;
 
-CSplineBoundaryConditionTestPath bc_path; 
-
 struct Scaler1DFixture  {
 	Scaler1DFixture(); 
 
@@ -130,9 +128,6 @@ Scaler1DFixture::Scaler1DFixture():
 	data(256, false)
 {
 
-	CPathNameArray  sksearchpath({bfs::path("splinekernel")});
-	CSplineKernelPluginHandler::set_search_path(sksearchpath); 
-	
 	const double intervall = 2 * M_PI / 255.0; 
 
 	for(size_t x = 0; x < 256; ++x)
