@@ -19,6 +19,10 @@
  */
 
 #include <climits>
+
+#define BOOST_TEST_MAIN
+#define BOOST_TEST_NO_MAIN
+
 #include <boost/test/unit_test_suite.hpp>
 #include <boost/test/unit_test.hpp>
 #include <boost/test/floating_point_comparison.hpp>
@@ -39,7 +43,9 @@ const SProgramDescription g_description = {
 	{pdi_short, "Linearly combine two 2D images."}, 
 	{pdi_description, "Merge two images by pixel-wise linearly combining their intensities."}, 
 	{pdi_example_descr, "Combine image inputA.v and inputB.v by using position coordinates "
-	 "4, 7, and 9 and write the result to output.v"}, 
+	 "4, 7, and 9. This means the output pixel values will be evaluated according to\n\n"
+	 "    (9-7)/(9-4) * A + (7-4)/(9-4) * B  \n\n"
+	 "The result image will be written to output.v"},
 	{pdi_example_code, "-1 inputA.v -2 inputB.v -p 4,7,9 -o output.v"}
 }; 
 
@@ -79,8 +85,9 @@ private:
 	float m_w;
 };
 
-static void run_self_test()
+BOOST_AUTO_TEST_CASE ( run_self_test )
 {
+	
 	const C2DBounds size(1,2);
 	
 	C2DFImage *A = new C2DFImage(size);
@@ -105,12 +112,8 @@ static void run_self_test()
 	
 }
 
-static bool init_unit_test_suite( )
-{
-	::boost::unit_test::framework::master_test_suite().add( BOOST_TEST_CASE( &run_self_test));
-	return true;
-}
 
+     
 template <typename F>
 struct FFilter {
 	FFilter(const F& f):
@@ -125,6 +128,8 @@ private:
 	const F& m_f;
 };
 
+SELFTEST_CALLBACK(CSelftest);
+
 int do_main(int argc, char **argv)
 {
 
@@ -132,7 +137,7 @@ int do_main(int argc, char **argv)
 	string src1_filename;
 	string src2_filename;
 	string out_filename;
-	bool self_test = false;
+	int self_test_result = 0;
 
 	vector<float> positions;
 
@@ -147,15 +152,17 @@ int do_main(int argc, char **argv)
 	options.add(make_opt( positions, "positions", 'p', 
 			      "image series positions (first, target, second)", 
 			      CCmdOptionFlags::required));
-	options.add(make_opt( self_test, "self-test", 0, "run a self test of the tool"));
+	options.add_selftest(self_test_result, new CSelftest(argc, argv));
 	
-	if (options.parse(argc, argv) != CCmdOptionList::hr_no)
+	switch (options.parse(argc, argv, "boost-test-options")) {
+	case CCmdOptionList::hr_no:
+		break; 
+	case CCmdOptionList::hr_selftest: 
+		return self_test_result; 
+	default: 
 		return EXIT_SUCCESS; 
-
-	if (self_test) {
-		return ::boost::unit_test::unit_test_main( &init_unit_test_suite, argc, (char **)argv );
 	}
-
+	
 	if (positions.size() != 3) {
 		stringstream msg;
 		msg << "positions must be 3 values: first, target, second, got " << positions.size() << "images";
