@@ -89,8 +89,8 @@ int do_main( int argc, char *argv[] )
 
 
 	CCmdOptionList options(g_description);
-	options.add(make_opt( src_name, "in", 'i', "input segmentation set", CCmdOptionFlags::required_input));
-	options.add(make_opt( out_name, "out", 'o', "output image of minimal correlation", 
+	options.add(make_opt( src_name, "in-set", 'i', "input segmentation set", CCmdOptionFlags::required_input));
+	options.add(make_opt( out_name, "out-set", 'o', "output image of minimal correlation", 
 			      CCmdOptionFlags::required_output,  &C2DImageIOPluginHandler::instance()));
 	options.add(make_opt( skip, "skip", 'k', "skip images at beginning of series"));
 
