@@ -171,7 +171,7 @@ int do_main( int argc, char *argv[] )
 	bool no_copy_images = false; 
 	
 	CCmdOptionList options(g_description);
-	options.add(make_opt( out_directory, "out", 'o', "output directory (needs to exist and be writable)", 
+	options.add(make_opt( out_directory, "out-directory", 'o', "output directory (needs to exist and be writable)", 
 			      CCmdOptionFlags::required_output));
 	options.add(make_opt( no_copy_images, "no-copy", 0, "don't copy image files to output directory"));
 
