@@ -72,13 +72,9 @@ int do_main( int argc, char *argv[] )
 	options.add(make_opt( in_filename, "in-file", 'i', "input image(s) to be filtered", CCmdOptionFlags::required_input, &imageio));
 	options.add(make_opt( out_filename, "out-file", 'o', "output file name base, numbers are added accorfing to the input "
 			      "file pattern, and the file  extension is added according to the 'type' option.", 
-			      CCmdOptionFlags::required, &imageio));
+			      CCmdOptionFlags::required_output, &imageio));
 	options.add(make_opt( out_type, imageio.get_set(), "type", 't',"output file type", CCmdOptionFlags::required));
 	
-	options.add(make_help_opt( "help-plugins", 0,
-				   "give some help about the filter plugins", 
-				   new TPluginHandlerHelpCallback<C3DFilterPluginHandler>)); 
-
 	if (options.parse(argc, argv, "filter", &filter_plugins) != CCmdOptionList::hr_no)
 		return EXIT_SUCCESS; 
 
