@@ -63,13 +63,13 @@ int do_main( int argc, char *argv[] )
 
 	CCmdOptionList options(g_description);
 	options.set_group("File I/O"); 
-	options.add(make_opt( src_filename, "in", 'i', "test image", 
+	options.add(make_opt( src_filename, "in-image", 'i', "test image", 
 			      CCmdOptionFlags::required_input, &C3DImageIOPluginHandler::instance()));
-	options.add(make_opt( ref_filename, "ref", 'r', "reference image", 
+	options.add(make_opt( ref_filename, "ref-image", 'r', "reference image", 
 			      CCmdOptionFlags::required_input, &C3DImageIOPluginHandler::instance()));
-	options.add(make_opt( out_filename, "out", 'o', "registered output image", 
+	options.add(make_opt( out_filename, "out-image", 'o', "registered output image", 
 			      CCmdOptionFlags::required_output, &C3DImageIOPluginHandler::instance()));
-	options.add(make_opt( trans_filename, "trans", 't', "transformation output file name", 
+	options.add(make_opt( trans_filename, "transformation", 't', "transformation output file name", 
 			      CCmdOptionFlags::output, &C3DTransformationIOPluginHandler::instance() ));
 
 	
