@@ -115,7 +115,7 @@ int do_main( int argc, char *argv[] )
 	CCmdOptionList options(g_description);
 	options.add(make_opt( in_filename, "in-file", 'i', "input image(s) to be filtered", 
 			      CCmdOptionFlags::required_input, &imageio));
-	options.add(make_opt( out_filename, "out", 'o', "output file name", 
+	options.add(make_opt( out_filename, "out-histogram", 'o', "output file name", 
 			      CCmdOptionFlags::required_output));
 	options.add(make_opt( hmin, "min", 0, "minimum of histogram range"));
 	options.add(make_opt( hmax, "max", 0, "maximum of histogram range"));
